@@ -2,9 +2,9 @@
 import unittest
 from mock import Mock, patch
 from flask import Flask
-from werkzeug import exceptions, MultiDict
+from werkzeug import exceptions
 from werkzeug.wrappers import Request
-from werkzeug.datastructures import FileStorage
+from werkzeug.datastructures import FileStorage, MultiDict
 from flask_restful.reqparse import Argument, RequestParser, Namespace
 import six
 import decimal
@@ -15,7 +15,7 @@ import json
 class ReqParseTestCase(unittest.TestCase):
     def test_default_help(self):
         arg = Argument("foo")
-        self.assertEquals(arg.help, None)
+        self.assertEqual(arg.help, None)
 
     @patch('flask_restful.abort')
     def test_help_with_error_msg(self, abort):
@@ -68,76 +68,76 @@ class ReqParseTestCase(unittest.TestCase):
 
     def test_name(self):
         arg = Argument("foo")
-        self.assertEquals(arg.name, "foo")
+        self.assertEqual(arg.name, "foo")
 
     def test_dest(self):
         arg = Argument("foo", dest="foobar")
-        self.assertEquals(arg.dest, "foobar")
+        self.assertEqual(arg.dest, "foobar")
 
     def test_location_url(self):
         arg = Argument("foo", location="url")
-        self.assertEquals(arg.location, "url")
+        self.assertEqual(arg.location, "url")
 
     def test_location_url_list(self):
         arg = Argument("foo", location=["url"])
-        self.assertEquals(arg.location, ["url"])
+        self.assertEqual(arg.location, ["url"])
 
     def test_location_header(self):
         arg = Argument("foo", location="headers")
-        self.assertEquals(arg.location, "headers")
+        self.assertEqual(arg.location, "headers")
 
     def test_location_json(self):
         arg = Argument("foo", location="json")
-        self.assertEquals(arg.location, "json")
+        self.assertEqual(arg.location, "json")
 
     def test_location_get_json(self):
         arg = Argument("foo", location="get_json")
-        self.assertEquals(arg.location, "get_json")
+        self.assertEqual(arg.location, "get_json")
 
     def test_location_header_list(self):
         arg = Argument("foo", location=["headers"])
-        self.assertEquals(arg.location, ["headers"])
+        self.assertEqual(arg.location, ["headers"])
 
     def test_type(self):
         arg = Argument("foo", type=int)
-        self.assertEquals(arg.type, int)
+        self.assertEqual(arg.type, int)
 
     def test_default(self):
         arg = Argument("foo", default=True)
-        self.assertEquals(arg.default, True)
+        self.assertEqual(arg.default, True)
 
     def test_required(self):
         arg = Argument("foo", required=True)
-        self.assertEquals(arg.required, True)
+        self.assertEqual(arg.required, True)
 
     def test_ignore(self):
         arg = Argument("foo", ignore=True)
-        self.assertEquals(arg.ignore, True)
+        self.assertEqual(arg.ignore, True)
 
     def test_operator(self):
         arg = Argument("foo", operators=[">=", "<=", "="])
-        self.assertEquals(arg.operators, [">=", "<=", "="])
+        self.assertEqual(arg.operators, [">=", "<=", "="])
 
     def test_action_filter(self):
         arg = Argument("foo", action="filter")
-        self.assertEquals(arg.action, u"filter")
+        self.assertEqual(arg.action, u"filter")
 
     def test_action(self):
         arg = Argument("foo", action="append")
-        self.assertEquals(arg.action, u"append")
+        self.assertEqual(arg.action, u"append")
 
     def test_choices(self):
         arg = Argument("foo", choices=[1, 2])
-        self.assertEquals(arg.choices, [1, 2])
+        self.assertEqual(arg.choices, [1, 2])
 
     def test_default_dest(self):
         arg = Argument("foo")
-        self.assertEquals(arg.dest, None)
+        self.assertEqual(arg.dest, None)
 
     def test_default_operators(self):
         arg = Argument("foo")
-        self.assertEquals(arg.operators[0], "=")
-        self.assertEquals(len(arg.operators), 1)
+        self.assertEqual(arg.operators[0], "=")
+        self.assertEqual(len(arg.operators), 1)
 
     @patch('flask_restful.reqparse.six')
     def test_default_type(self, mock_six):
@@ -148,37 +148,37 @@ class ReqParseTestCase(unittest.TestCase):
 
     def test_default_default(self):
         arg = Argument("foo")
-        self.assertEquals(arg.default, None)
+        self.assertEqual(arg.default, None)
 
     def test_required_default(self):
         arg = Argument("foo")
-        self.assertEquals(arg.required, False)
+        self.assertEqual(arg.required, False)
 
     def test_ignore_default(self):
         arg = Argument("foo")
-        self.assertEquals(arg.ignore, False)
+        self.assertEqual(arg.ignore, False)
 
     def test_action_default(self):
         arg = Argument("foo")
-        self.assertEquals(arg.action, u"store")
+        self.assertEqual(arg.action, u"store")
 
     def test_choices_default(self):
         arg = Argument("foo")
-        self.assertEquals(len(arg.choices), 0)
+        self.assertEqual(len(arg.choices), 0)
 
     def test_source(self):
         req = Mock(['args', 'headers', 'values'])
         req.args = {'foo': 'bar'}
         req.headers = {'baz': 'bat'}
         arg = Argument('foo', location=['args'])
-        self.assertEquals(arg.source(req), MultiDict(req.args))
+        self.assertEqual(arg.source(req), MultiDict(req.args))
 
         arg = Argument('foo', location=['headers'])
-        self.assertEquals(arg.source(req), MultiDict(req.headers))
+        self.assertEqual(arg.source(req), MultiDict(req.headers))
 
     def test_convert_default_type_with_null_input(self):
         arg = Argument('foo')
-        self.assertEquals(arg.convert(None, None), None)
+        self.assertEqual(arg.convert(None, None), None)
 
     def test_convert_with_null_input_when_not_nullable(self):
         arg = Argument('foo', nullable=False)
@@ -193,19 +193,19 @@ class ReqParseTestCase(unittest.TestCase):
         req = Mock(['values'])
         req._get_child_mock = lambda **kwargs: MultiDict()
         arg = Argument('foo')
-        self.assertEquals(arg.source(req), req.values)
+        self.assertEqual(arg.source(req), req.values)
 
     def test_option_case_sensitive(self):
         arg = Argument("foo", choices=["bar", "baz"], case_sensitive=True)
-        self.assertEquals(True, arg.case_sensitive)
+        self.assertEqual(True, arg.case_sensitive)
 
         # Insensitive
         arg = Argument("foo", choices=["bar", "baz"], case_sensitive=False)
-        self.assertEquals(False, arg.case_sensitive)
+        self.assertEqual(False, arg.case_sensitive)
 
         # Default
         arg = Argument("foo", choices=["bar", "baz"])
-        self.assertEquals(True, arg.case_sensitive)
+        self.assertEqual(True, arg.case_sensitive)
 
     def test_viewargs(self):
         req = Request.from_values()
@@ -213,7 +213,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser = RequestParser()
         parser.add_argument("foo", location=["view_args"])
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
         req = Mock()
         req.values = ()
@@ -222,7 +222,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser = RequestParser()
         parser.add_argument("foo", store_missing=True)
         args = parser.parse_args(req)
-        self.assertEquals(args["foo"], None)
+        self.assertEqual(args["foo"], None)
 
     def test_parse_unicode(self):
         req = Request.from_values("/bubble?foo=barß")
@@ -230,7 +230,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo")
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], u"barß")
+        self.assertEqual(args['foo'], u"barß")
 
     def test_parse_unicode_app(self):
         app = Flask(__name__)
@@ -240,7 +240,7 @@ class ReqParseTestCase(unittest.TestCase):
 
         with app.test_request_context('/bubble?foo=barß'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], u"barß")
+            self.assertEqual(args['foo'], u"barß")
 
     def test_json_location(self):
         app = Flask(__name__)
@@ -250,7 +250,7 @@ class ReqParseTestCase(unittest.TestCase):
 
         with app.test_request_context('/bubble', method="post"):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], None)
+            self.assertEqual(args['foo'], None)
 
     def test_get_json_location(self):
         app = Flask(__name__)
@@ -262,7 +262,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": "bar"}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], 'bar')
+            self.assertEqual(args['foo'], 'bar')
 
     def test_parse_append_ignore(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -272,7 +272,7 @@ class ReqParseTestCase(unittest.TestCase):
                             store_missing=True),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], None)
+        self.assertEqual(args['foo'], None)
 
     def test_parse_append_default(self):
         req = Request.from_values("/bubble?")
@@ -281,7 +281,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", action="append", store_missing=True),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], None)
+        self.assertEqual(args['foo'], None)
 
     def test_parse_append(self):
         req = Request.from_values("/bubble?foo=bar&foo=bat")
@@ -290,7 +290,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", action="append"),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ["bar", "bat"])
+        self.assertEqual(args['foo'], ["bar", "bat"])
 
     def test_parse_append_single(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -299,7 +299,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", action="append"),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ["bar"])
+        self.assertEqual(args['foo'], ["bar"])
 
     def test_parse_append_many(self):
         req = Request.from_values("/bubble?foo=bar&foo=bar2")
@@ -308,7 +308,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", action="append"),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ["bar", "bar2"])
+        self.assertEqual(args['foo'], ["bar", "bar2"])
 
     def test_parse_append_many_location_json(self):
         app = Flask(__name__)
@@ -320,7 +320,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": ["bar", "bar2"]}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], ['bar', 'bar2'])
+            self.assertEqual(args['foo'], ['bar', 'bar2'])
 
     def test_parse_dest(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -329,7 +329,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", dest="bat")
 
         args = parser.parse_args(req)
-        self.assertEquals(args['bat'], "bar")
+        self.assertEqual(args['bat'], "bar")
 
     def test_parse_gte_lte_eq(self):
         req = Request.from_values("/bubble?foo>=bar&foo<=bat&foo=foo")
@@ -338,7 +338,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", operators=[">=", "<=", "="], action="append"),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ["bar", "bat", "foo"])
+        self.assertEqual(args['foo'], ["bar", "bat", "foo"])
 
     def test_parse_gte(self):
         req = Request.from_values("/bubble?foo>=bar")
@@ -347,7 +347,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", operators=[">="])
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_foo_operators_four_hunderd(self):
         app = Flask(__name__)
@@ -362,7 +362,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", ignore=True, store_missing=True)
 
         args = parser.parse_args(Request.from_values("/bubble"))
-        self.assertEquals(args['foo'], None)
+        self.assertEqual(args['foo'], None)
 
     def test_parse_lte_gte_mock(self):
         mock_type = Mock()
@@ -379,26 +379,26 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", operators=["<=", "="], action="append")
 
         args = parser.parse_args(Request.from_values("/bubble?foo<=bar"))
-        self.assertEquals(args['foo'], ["bar"])
+        self.assertEqual(args['foo'], ["bar"])
 
     def test_parse_lte_gte_missing(self):
         parser = RequestParser()
         parser.add_argument("foo", operators=["<=", "="])
         args = parser.parse_args(Request.from_values("/bubble?foo<=bar"))
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_eq_other(self):
         parser = RequestParser()
         parser.add_argument("foo"),
         args = parser.parse_args(Request.from_values("/bubble?foo=bar&foo=bat"))
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_eq(self):
         req = Request.from_values("/bubble?foo=bar")
         parser = RequestParser()
         parser.add_argument("foo"),
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_lte(self):
         req = Request.from_values("/bubble?foo<=bar")
@@ -406,7 +406,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", operators=["<="])
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_required(self):
         app = Flask(__name__)
@@ -422,7 +422,7 @@ class ReqParseTestCase(unittest.TestCase):
             except exceptions.BadRequest as e:
                 message = e.data['message']
 
-            self.assertEquals(message, ({'foo': 'Missing required parameter in '
+            self.assertEqual(message, ({'foo': 'Missing required parameter in '
                                                 'the post body or the query '
                                                 'string'}))
 
@@ -433,7 +433,7 @@ class ReqParseTestCase(unittest.TestCase):
                 parser.parse_args(req)
             except exceptions.BadRequest as e:
                 message = e.data['message']
-            self.assertEquals(message, ({'bar': 'Missing required parameter in '
+            self.assertEqual(message, ({'bar': 'Missing required parameter in '
                                                 'the post body or the query '
                                                 'string or the request\'s '
                                                 'cookies'}))
@@ -458,7 +458,7 @@ class ReqParseTestCase(unittest.TestCase):
                              'bar': 'Missing required parameter in the post '
                                     'body or the query string or the '
                                     'request\'s cookies'}
-            self.assertEquals(message, error_message)
+            self.assertEqual(message, error_message)
 
     def test_parse_error_bundling_w_parser_arg(self):
         app = Flask(__name__)
@@ -480,7 +480,7 @@ class ReqParseTestCase(unittest.TestCase):
                              'bar': 'Missing required parameter in the post '
                              'body or the query string or the request\'s '
                              'cookies'}
-            self.assertEquals(message, error_message)
+            self.assertEqual(message, error_message)
 
     def test_parse_default_append(self):
         req = Request.from_values("/bubble")
@@ -490,7 +490,7 @@ class ReqParseTestCase(unittest.TestCase):
 
         args = parser.parse_args(req)
 
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_default(self):
         req = Request.from_values("/bubble")
@@ -499,7 +499,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", default="bar", store_missing=True)
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_callable_default(self):
         req = Request.from_values("/bubble")
@@ -508,7 +508,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", default=lambda: "bar", store_missing=True)
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -517,7 +517,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo"),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bar")
+        self.assertEqual(args['foo'], "bar")
 
     def test_parse_none(self):
         req = Request.from_values("/bubble")
@@ -526,7 +526,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo")
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], None)
+        self.assertEqual(args['foo'], None)
 
     def test_parse_store_missing(self):
         req = Request.from_values("/bubble")
@@ -544,7 +544,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", choices=["bat"]),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "bat")
+        self.assertEqual(args['foo'], "bat")
 
     def test_parse_choices(self):
         app = Flask(__name__)
@@ -573,7 +573,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", choices=["bat"], case_sensitive=False),
 
         args = parser.parse_args(req)
-        self.assertEquals('bat', args.get('foo'))
+        self.assertEqual('bat', args.get('foo'))
 
         # both choices and args are case_insensitive
         req = Request.from_values("/bubble?foo=bat")
@@ -582,7 +582,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", choices=["BAT"], case_sensitive=False),
 
         args = parser.parse_args(req)
-        self.assertEquals('bat', args.get('foo'))
+        self.assertEqual('bat', args.get('foo'))
 
     def test_parse_ignore(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -591,7 +591,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", type=int, ignore=True, store_missing=True),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], None)
+        self.assertEqual(args['foo'], None)
 
     def test_chaining(self):
         parser = RequestParser()
@@ -601,8 +601,8 @@ class ReqParseTestCase(unittest.TestCase):
         namespace = Namespace()
         namespace.foo = 'bar'
         namespace['bar'] = 'baz'
-        self.assertEquals(namespace['foo'], 'bar')
-        self.assertEquals(namespace.bar, 'baz')
+        self.assertEqual(namespace['foo'], 'bar')
+        self.assertEqual(namespace.bar, 'baz')
 
     def test_namespace_missing(self):
         namespace = Namespace()
@@ -624,7 +624,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": None}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], None)
+            self.assertEqual(args['foo'], None)
 
     def test_type_callable(self):
         req = Request.from_values("/bubble?foo=1")
@@ -633,7 +633,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument("foo", type=lambda x: x, required=False),
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], "1")
+        self.assertEqual(args['foo'], "1")
 
     def test_type_callable_none(self):
         app = Flask(__name__)
@@ -646,7 +646,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       content_type='application/json'):
             try:
                 args = parser.parse_args()
-                self.assertEquals(args['foo'], None)
+                self.assertEqual(args['foo'], None)
             except exceptions.BadRequest:
                 self.fail()
 
@@ -660,7 +660,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": "1.0025"}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], decimal.Decimal("1.0025"))
+            self.assertEqual(args['foo'], decimal.Decimal("1.0025"))
 
 
     def test_type_hard_decimal(self):
@@ -673,7 +673,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": 89.92}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], decimal.Decimal("89.92"))
+            self.assertEqual(args['foo'], decimal.Decimal("89.92"))
 
     def test_type_filestorage(self):
         app = Flask(__name__)
@@ -686,9 +686,9 @@ class ReqParseTestCase(unittest.TestCase):
                                       data={'foo': (six.BytesIO(fdata), 'baz.txt')}):
             args = parser.parse_args()
 
-            self.assertEquals(args['foo'].name, 'foo')
-            self.assertEquals(args['foo'].filename, 'baz.txt')
-            self.assertEquals(args['foo'].read(), fdata)
+            self.assertEqual(args['foo'].name, 'foo')
+            self.assertEqual(args['foo'].filename, 'baz.txt')
+            self.assertEqual(args['foo'].read(), fdata)
 
     def test_filestorage_custom_type(self):
         def _custom_type(f):
@@ -706,9 +706,9 @@ class ReqParseTestCase(unittest.TestCase):
                                       data={'foo': (six.BytesIO(fdata), 'baz.txt')}):
             args = parser.parse_args()
 
-            self.assertEquals(args['foo'].name, 'fooaaaa')
-            self.assertEquals(args['foo'].filename, 'baz.txtaaaa')
-            self.assertEquals(args['foo'].read(), fdata)
+            self.assertEqual(args['foo'].name, 'fooaaaa')
+            self.assertEqual(args['foo'].filename, 'baz.txtaaaa')
+            self.assertEqual(args['foo'].read(), fdata)
 
     def test_passing_arguments_object(self):
         req = Request.from_values("/bubble?foo=bar")
@@ -716,7 +716,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser.add_argument(Argument("foo"))
 
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], u"bar")
+        self.assertEqual(args['foo'], u"bar")
 
     def test_int_choice_types(self):
         app = Flask(__name__)
@@ -767,8 +767,8 @@ class ReqParseTestCase(unittest.TestCase):
         self.assertFalse(bar_arg in parser.args)
 
         args = parser_copy.parse_args(req)
-        self.assertEquals(args['foo'], 101)
-        self.assertEquals(args['bar'], u'baz')
+        self.assertEqual(args['foo'], 101)
+        self.assertEqual(args['bar'], u'baz')
 
     def test_request_parse_copy_including_settings(self):
         parser = RequestParser(trim=True, bundle_errors=True)
@@ -785,7 +785,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser_copy.replace_argument('foo')
 
         args = parser_copy.parse_args(req)
-        self.assertEquals(args['foo'], u'baz')
+        self.assertEqual(args['foo'], u'baz')
 
     def test_both_json_and_values_location(self):
 
@@ -798,8 +798,8 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"baz": 2}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], 1)
-            self.assertEquals(args['baz'], 2)
+            self.assertEqual(args['foo'], 1)
+            self.assertEqual(args['baz'], 2)
 
     def test_not_json_location_and_content_type_json(self):
         app = Flask(__name__)
@@ -819,13 +819,13 @@ class ReqParseTestCase(unittest.TestCase):
         parser_copy.remove_argument('foo')
 
         args = parser_copy.parse_args(req)
-        self.assertEquals(args, {})
+        self.assertEqual(args, {})
 
     def test_strict_parsing_off(self):
         req = Request.from_values("/bubble?foo=baz")
         parser = RequestParser()
         args = parser.parse_args(req)
-        self.assertEquals(args, {})
+        self.assertEqual(args, {})
 
     def test_strict_parsing_on(self):
         req = Request.from_values("/bubble?foo=baz")
@@ -837,7 +837,7 @@ class ReqParseTestCase(unittest.TestCase):
         parser = RequestParser()
         parser.add_argument('foo', type=int)
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], 1)
+        self.assertEqual(args['foo'], 1)
 
     def test_strict_parsing_on_partial_hit(self):
         req = Request.from_values("/bubble?foo=1&bar=bees&n=22")
@@ -850,34 +850,34 @@ class ReqParseTestCase(unittest.TestCase):
         parser = RequestParser()
         parser.add_argument('foo')
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ' 1 ')
+        self.assertEqual(args['foo'], ' 1 ')
 
         parser = RequestParser()
         parser.add_argument('foo', trim=True)
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], '1')
+        self.assertEqual(args['foo'], '1')
 
         parser = RequestParser()
         parser.add_argument('foo', trim=True, type=int)
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], 1)
+        self.assertEqual(args['foo'], 1)
 
     def test_trim_request_parser(self):
         req = Request.from_values("/bubble?foo= 1 &bar=bees&n=22")
         parser = RequestParser(trim=False)
         parser.add_argument('foo')
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], ' 1 ')
+        self.assertEqual(args['foo'], ' 1 ')
 
         parser = RequestParser(trim=True)
         parser.add_argument('foo')
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], '1')
+        self.assertEqual(args['foo'], '1')
 
         parser = RequestParser(trim=True)
         parser.add_argument('foo', type=int)
         args = parser.parse_args(req)
-        self.assertEquals(args['foo'], 1)
+        self.assertEqual(args['foo'], 1)
 
     def test_trim_request_parser_override_by_argument(self):
         parser = RequestParser(trim=True)
@@ -897,9 +897,9 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({"foo": " bar ", "int1": 1, "int2": " 2 "}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['foo'], 'bar')
-            self.assertEquals(args['int1'], 1)
-            self.assertEquals(args['int2'], 2)
+            self.assertEqual(args['foo'], 'bar')
+            self.assertEqual(args['int1'], 1)
+            self.assertEqual(args['int2'], 2)
 
     def test_list_argument(self):
         app = Flask(__name__)
@@ -911,7 +911,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({'arg1': ['foo', 'bar']}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['arg1'], ['foo', 'bar'])
+            self.assertEqual(args['arg1'], ['foo', 'bar'])
 
     def test_list_argument_dict(self):
         app = Flask(__name__)
@@ -923,7 +923,7 @@ class ReqParseTestCase(unittest.TestCase):
                                       data=json.dumps({'arg1': [{'foo': 1, 'bar': 2}]}),
                                       content_type='application/json'):
             args = parser.parse_args()
-            self.assertEquals(args['arg1'], [{'foo': 1, 'bar': 2}])
+            self.assertEqual(args['arg1'], [{'foo': 1, 'bar': 2}])
 
     def test_argument_repr(self):
         arg = Argument('foo')
